==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001_result/MP0118_GetGridHeaderData_001_Result.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}GRIDRESULT"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "gridresult"
})
@XmlRootElement(name = "MP0118_GetGridHeaderData_001_Result")
public class MP0118_GetGridHeaderData_001_Result {

    @XmlElement(name = "GRIDRESULT", required = true)
    protected GRIDRESULT gridresult;

    /**
     * Obtient la valeur de la propriété gridresult.
     * 
     * @return
     *     possible object is
     *     {@link GRIDRESULT }
     *     
     */
    public GRIDRESULT getGRIDRESULT() {
        return gridresult;
    }

    /**
     * Définit la valeur de la propriété gridresult.
     * 
     * @param value
     *     allowed object is
     *     {@link GRIDRESULT }
     *     
     */
    public void setGRIDRESULT(GRIDRESULT value) {
        this.gridresult = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001_result/MP0118_GetGridHeaderData_001_Result.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}GRIDRESULT"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "gridresult"
})
@XmlRootElement(name = "MP0118_GetGridHeaderData_001_Result")
public class MP0118_GetGridHeaderData_001_Result {

    @XmlElement(name = "GRIDRESULT", required = true)
    protected GRIDRESULT gridresult;

    /**
     * Gets the value of the gridresult property.
     * 
     * @return
     *     possible object is
     *     {@link GRIDRESULT }
     *     
     */
    public GRIDRESULT getGRIDRESULT() {
        return gridresult;
    }

    /**
     * Sets the value of the gridresult property.
     * 
     * @param value
     *     allowed object is
     *     {@link GRIDRESULT }
     *     
     */
    public void setGRIDRESULT(GRIDRESULT value) {
        this.gridresult = value;
    }

}
